==> trilinos_12.8.1.orig.tar.bz2: trilinos-12.8.1-Source/packages/muelu/src/Utils/ExplicitInstantiation/ETI_SC_LO_GO_NO_classes.cmake <==
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::AggregationExportFactory )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::AmalgamationFactory )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::Amesos2Smoother-.?if.defined[HAVE_MUELU_TPETRA].&&.defined[HAVE_MUELU_AMESOS2] )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::AMGXOperator-.?if.defined[HAVE_MUELU_EXPERIMENTAL].&&.defined[HAVE_MUELU_AMGX] )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::AlgebraicPermutationStrategy )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::BlockedCoarseMapFactory-.?ifdef.HAVE_MUELU_EXPERIMENTAL )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::BlockedDirectSolver-.?ifdef.HAVE_MUELU_EXPERIMENTAL )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::BlockedGaussSeidelSmoother-.?ifdef.HAVE_MUELU_EXPERIMENTAL )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::BlockedPFactory-.?ifdef.HAVE_MUELU_EXPERIMENTAL )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::BlockedRAPFactory-.?ifdef.HAVE_MUELU_EXPERIMENTAL )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::BrickAggregationFactory )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::BraessSarazinSmoother-.?ifdef.HAVE_MUELU_EXPERIMENTAL )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::CGSolver )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::CoalesceDropFactory )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::CoalesceDropFactory_kokkos-.?if.defined[HAVE_MUELU_KOKKOS_REFACTOR] )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::CoarseMapFactory )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::CoarseMapFactory_kokkos-.?if.defined[HAVE_MUELU_KOKKOS_REFACTOR] )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::CoarseningVisualizationFactory )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::Constraint )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::ConstraintFactory )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::CoordinatesTransferFactory )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::CoordinatesTransferFactory_kokkos-.?if.defined[HAVE_MUELU_KOKKOS_REFACTOR] )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::CoupledRBMFactory )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::DemoFactory )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::DirectSolver )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::DropNegativeEntriesFactory )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::EminPFactory )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::FactoryManager )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::FilteredAFactory )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::FilteredAFactory_kokkos-.?if.defined[HAVE_MUELU_KOKKOS_REFACTOR] )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::GenericRFactory )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::GMRESSolver )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::Hierarchy )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::HierarchyUtils )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::Ifpack2Smoother-.?if.defined[HAVE_MUELU_TPETRA].&&.defined[HAVE_MUELU_IFPACK2] )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::IndefBlockedDiagonalSmoother-.?ifdef.HAVE_MUELU_EXPERIMENTAL )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::LineDetectionFactory )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::LocalPermutationStrategy )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::MapTransferFactory )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::MatrixAnalysisFactory )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::MergedBlockedMatrixFactory-.?ifdef.HAVE_MUELU_EXPERIMENTAL )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::MergedSmoother )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::MultiVectorTransferFactory )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::NullspaceFactory )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::NullspaceFactory_kokkos-.?if.defined[HAVE_MUELU_KOKKOS_REFACTOR] )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::NullspacePresmoothFactory )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::PatternFactory )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::PerfUtils )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::PermutationFactory )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::PermutingSmoother )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::PgPFactory )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::PreDropFunctionConstVal )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::ProjectorSmoother )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::RAPFactory )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::RAPShiftFactory )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::RebalanceAcFactory )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::RebalanceBlockAcFactory-.?ifdef.HAVE_MUELU_EXPERIMENTAL )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::RebalanceBlockInterpolationFactory-.?ifdef.HAVE_MUELU_EXPERIMENTAL )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::RebalanceBlockRestrictionFactory-.?ifdef.HAVE_MUELU_EXPERIMENTAL )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::RebalanceTransferFactory )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::ReorderBlockAFactory )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::RepartitionFactory-.?ifdef.HAVE_MPI )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::RigidBodyModeFactory )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::SaPFactory )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::SaPFactory_kokkos-.?if.defined[HAVE_MUELU_KOKKOS_REFACTOR] )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::SchurComplementFactory-.?ifdef.HAVE_MUELU_EXPERIMENTAL )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::SegregatedAFactory )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::ShiftedLaplacian-.?if.defined[HAVE_MUELU_TPETRA].&&.defined[HAVE_MUELU_IFPACK2].&&.defined[HAVE_MUELU_BELOS].&&.defined[HAVE_MUELU_TPETRA_INST_INT_INT] )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::ShiftedLaplacianOperator-.?if.defined[HAVE_MUELU_TPETRA].&&.defined[HAVE_MUELU_BELOS].&&.defined[HAVE_MUELU_TPETRA_INST_INT_INT] )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::SimpleSmoother-.?ifdef.HAVE_MUELU_EXPERIMENTAL )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::SmootherFactory )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::SmootherPrototype )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::SteepestDescentSolver )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::SubBlockAFactory )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::TekoSmoother-.?if.defined[HAVE_MUELU_EXPERIMENTAL].&&.defined[HAVE_MUELU_TEKO] )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::TentativePFactory )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::TentativePFactory_kokkos-.?if.defined[HAVE_MUELU_KOKKOS_REFACTOR] )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::ThresholdAFilterFactory )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::ToggleCoordinatesTransferFactory )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::TogglePFactory )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::TopRAPFactory )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::TopSmootherFactory )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::TpetraOperator )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::TransPFactory )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::TrilinosSmoother )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::UserPFactory )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::Utilities )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::UtilitiesBase )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::Utilities_kokkos-.?if.defined[HAVE_MUELU_KOKKOS_REFACTOR] )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::SemiCoarsenPFactory )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::UzawaSmoother-.?ifdef.HAVE_MUELU_EXPERIMENTAL )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::VisualizationHelpers )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::ZoltanInterface-.?if.defined[HAVE_MUELU_ZOLTAN].&&.defined[HAVE_MPI] )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::Zoltan2Interface-.?if.defined[HAVE_MUELU_ZOLTAN2].&&.defined[HAVE_MPI] )

==> trilinos_12.10.1.orig.tar.bz2: trilinos-12.10.1-Source/packages/muelu/src/Utils/ExplicitInstantiation/ETI_SC_LO_GO_NO_classes.cmake <==
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::AggregationExportFactory )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::AmalgamationFactory )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::Amesos2Smoother-.?if.defined[HAVE_MUELU_TPETRA].&&.defined[HAVE_MUELU_AMESOS2] )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::AMGXOperator-.?if.defined[HAVE_MUELU_EXPERIMENTAL].&&.defined[HAVE_MUELU_AMGX] )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::AlgebraicPermutationStrategy )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::BlockedCoarseMapFactory-.?ifdef.HAVE_MUELU_EXPERIMENTAL )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::BlockedDirectSolver-.?ifdef.HAVE_MUELU_EXPERIMENTAL )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::BlockedGaussSeidelSmoother-.?ifdef.HAVE_MUELU_EXPERIMENTAL )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::BlockedPFactory-.?ifdef.HAVE_MUELU_EXPERIMENTAL )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::BlockedRAPFactory-.?ifdef.HAVE_MUELU_EXPERIMENTAL )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::BrickAggregationFactory )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::BraessSarazinSmoother-.?ifdef.HAVE_MUELU_EXPERIMENTAL )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::CGSolver )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::CloneRepartitionInterface )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::CoalesceDropFactory )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::CoalesceDropFactory_kokkos-.?if.defined[HAVE_MUELU_KOKKOS_REFACTOR] )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::CoarseMapFactory )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::CoarseMapFactory_kokkos-.?if.defined[HAVE_MUELU_KOKKOS_REFACTOR] )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::CoarseningVisualizationFactory )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::Constraint )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::ConstraintFactory )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::CoordinatesTransferFactory )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::CoordinatesTransferFactory_kokkos-.?if.defined[HAVE_MUELU_KOKKOS_REFACTOR] )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::CoupledRBMFactory )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::DemoFactory )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::DirectSolver )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::DropNegativeEntriesFactory )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::EminPFactory )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::FactoryManager )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::FilteredAFactory )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::FilteredAFactory_kokkos-.?if.defined[HAVE_MUELU_KOKKOS_REFACTOR] )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::GenericRFactory )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::GMRESSolver )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::Hierarchy )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::HierarchyUtils )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::Ifpack2Smoother-.?if.defined[HAVE_MUELU_TPETRA].&&.defined[HAVE_MUELU_IFPACK2] )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::IndefBlockedDiagonalSmoother-.?ifdef.HAVE_MUELU_EXPERIMENTAL )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::LineDetectionFactory )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::LocalPermutationStrategy )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::MapTransferFactory )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::MatrixAnalysisFactory )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::MergedBlockedMatrixFactory-.?ifdef.HAVE_MUELU_EXPERIMENTAL )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::MergedSmoother )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::MultiVectorTransferFactory )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::NullspaceFactory )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::NullspaceFactory_kokkos-.?if.defined[HAVE_MUELU_KOKKOS_REFACTOR] )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::NullspacePresmoothFactory )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::PatternFactory )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::PerfUtils )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::PermutationFactory )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::PermutingSmoother )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::PgPFactory )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::PreDropFunctionConstVal )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::ProjectorSmoother )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::RAPFactory )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::RAPShiftFactory )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::RebalanceAcFactory )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::RebalanceBlockAcFactory-.?ifdef.HAVE_MUELU_EXPERIMENTAL )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::RebalanceBlockInterpolationFactory-.?ifdef.HAVE_MUELU_EXPERIMENTAL )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::RebalanceBlockRestrictionFactory-.?ifdef.HAVE_MUELU_EXPERIMENTAL )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::RebalanceTransferFactory )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::ReorderBlockAFactory )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::RepartitionFactory-.?ifdef.HAVE_MPI )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::RepartitionHeuristicFactory-.?ifdef.HAVE_MPI )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::RigidBodyModeFactory )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::SaPFactory )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::SaPFactory_kokkos-.?if.defined[HAVE_MUELU_KOKKOS_REFACTOR] )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::SchurComplementFactory-.?ifdef.HAVE_MUELU_EXPERIMENTAL )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::SegregatedAFactory )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::ShiftedLaplacian-.?if.defined[HAVE_MUELU_TPETRA].&&.defined[HAVE_MUELU_IFPACK2].&&.defined[HAVE_MUELU_BELOS].&&.defined[HAVE_MUELU_TPETRA_INST_INT_INT] )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::ShiftedLaplacianOperator-.?if.defined[HAVE_MUELU_TPETRA].&&.defined[HAVE_MUELU_BELOS].&&.defined[HAVE_MUELU_TPETRA_INST_INT_INT] )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::SimpleSmoother-.?ifdef.HAVE_MUELU_EXPERIMENTAL )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::SmootherFactory )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::SmootherPrototype )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::SteepestDescentSolver )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::SubBlockAFactory )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::TekoSmoother-.?if.defined[HAVE_MUELU_EXPERIMENTAL].&&.defined[HAVE_MUELU_TEKO] )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::TentativePFactory )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::TentativePFactory_kokkos-.?if.defined[HAVE_MUELU_KOKKOS_REFACTOR] )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::ThresholdAFilterFactory )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::ToggleCoordinatesTransferFactory )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::TogglePFactory )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::TopRAPFactory )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::TopSmootherFactory )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::TpetraOperator )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::TransPFactory )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::TrilinosSmoother )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::UserPFactory )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::Utilities )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::UtilitiesBase )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::Utilities_kokkos-.?if.defined[HAVE_MUELU_KOKKOS_REFACTOR] )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::SemiCoarsenPFactory )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::UzawaSmoother-.?ifdef.HAVE_MUELU_EXPERIMENTAL )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::VisualizationHelpers )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::ZoltanInterface-.?if.defined[HAVE_MUELU_ZOLTAN].&&.defined[HAVE_MPI] )
APPEND_SET(MUELU_SC_LO_GO_NO_ETI_CLASSES MueLu::Zoltan2Interface-.?if.defined[HAVE_MUELU_ZOLTAN2].&&.defined[HAVE_MPI] )
